package com.ruoyi.web.controller.platform;


import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.BasicLibrary;
import com.ruoyi.system.service.BasicLibraryService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 红外遥控基础库管理Controller
 * 
 * @author liming
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/platform/v1/base")
public class BasicLibraryController extends BaseController {
    @Autowired
    private BasicLibraryService basicLibraryService;

    /**
     * 查询基础库管理列表
     */
    @ApiOperation("查询基础库管理列表")
    @PreAuthorize("@ss.hasPermi('platform:base:list')")
    @GetMapping("/list")
    public TableDataInfo list(BasicLibrary basicLibrary)
    {
        startPage();
        List<BasicLibrary> list = basicLibraryService.selectBasicLibraryList(basicLibrary);
        return getDataTable(list);
    }


    // TODO: 2023/7/13  这里做分页测试
    @GetMapping("/test")
    public R<List<BasicLibrary>> test(BasicLibrary basicLibrary)
    {
//        Page<List<BasicLibrary>> list2 = basicLibraryService.selectBasicLibraryList(basicLibrary);
        return R.ok();
    }

    
    /**
     * 获取红外遥控基础库管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('platform:base:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(basicLibraryService.selectBasicLibraryById(id));
    }

    /**
     * 新增红外遥控基础库管理
     */
//    @PreAuthorize("@ss.hasPermi('platform:base:add')")
//    @Log(title = "红外遥控基础库管理", businessType = BusinessType.INSERT)
    @PostMapping("add")
    public AjaxResult add(@RequestBody BasicLibrary basicLibrary)
    {
        // TODO: 2023/7/12 校验参数必须是26的倍数
        return toAjax(basicLibraryService.insertBasicLibrary(basicLibrary));
    }

    /**
     * 修改红外遥控基础库管理
     */
    @PreAuthorize("@ss.hasPermi('platform:base:edit')")
    @Log(title = "红外遥控基础库管理", businessType = BusinessType.UPDATE)
    @PutMapping("update")
    public AjaxResult edit(@RequestBody BasicLibrary basicLibrary)
    {
        return toAjax(basicLibraryService.updateBasicLibrary(basicLibrary));
    }

    /**
     * 删除红外遥控基础库管理
     */
    @PreAuthorize("@ss.hasPermi('platform:base:remove')")
    @Log(title = "红外遥控基础库管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(basicLibraryService.deleteBasicLibraryByIds(ids));
    }
}
