package com.ruoyi.web.controller.platform;

import java.util.List;

import com.ruoyi.system.domain.ComponentsLibrary;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.service.ComponentsLibraryService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 红外遥控组件库Controller
 *
 * @author liming
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/platform/v1/init")
public class ComponentsLibraryController extends BaseController
{
    @Autowired
    private ComponentsLibraryService componentsLibraryService;

    /**
     * 查询红外遥控组件库列表
     */
    @PreAuthorize("@ss.hasPermi('platform:components:list')")
    @GetMapping("/list")
    public TableDataInfo list(ComponentsLibrary componentsLibrary)
    {
        startPage();
        List<ComponentsLibrary> list = componentsLibraryService.selectComponentsLibraryList(componentsLibrary);
        return getDataTable(list);
    }


    /**
     * 获取红外遥控组件库详细信息
     */
    @PreAuthorize("@ss.hasPermi('platform:components:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(componentsLibraryService.selectComponentsLibraryById(id));
    }

    /**
     * 新增红外遥控组件库
     */
    @PreAuthorize("@ss.hasPermi('platform:components:add')")
    @Log(title = "红外遥控组件库", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ComponentsLibrary componentsLibrary)
    {
        return toAjax(componentsLibraryService.insertComponentsLibrary(componentsLibrary));
    }

    /**
     * 修改红外遥控组件库
     */
    @PreAuthorize("@ss.hasPermi('platform:components:edit')")
    @Log(title = "红外遥控组件库", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ComponentsLibrary componentsLibrary)
    {
        return toAjax(componentsLibraryService.updateComponentsLibrary(componentsLibrary));
    }

    /**
     * 删除红外遥控组件库
     */
    @PreAuthorize("@ss.hasPermi('platform:components:remove')")
    @Log(title = "红外遥控组件库", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(componentsLibraryService.deleteComponentsLibraryByIds(ids));
    }
}
