package com.ruoyi.web.controller.platform;

import java.util.List;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.QrLibrary;
import com.ruoyi.system.service.QrLibraryService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 红外遥控二维码Controller
 *
 * @author liming
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/platform/v1/or")
public class QrLibraryController extends BaseController
{
    @Autowired
    private QrLibraryService qrLibraryService;

    /**
     * 查询红外遥控二维码列表
     */
    @PreAuthorize("@ss.hasPermi('platform:or:list')")
    @GetMapping("/list")
    public TableDataInfo list(QrLibrary qrLibrary)
    {
        startPage();
        List<QrLibrary> list = qrLibraryService.selectQrLibraryList(qrLibrary);
        return getDataTable(list);
    }


    /**
     * 获取红外遥控二维码详细信息
     */
    @PreAuthorize("@ss.hasPermi('platform:or:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(qrLibraryService.selectQrLibraryById(id));
    }

    /**
     * 新增红外遥控二维码
     */
    @PreAuthorize("@ss.hasPermi('platform:or:add')")
    @Log(title = "红外遥控二维码", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QrLibrary qrLibrary)
    {
        return toAjax(qrLibraryService.insertQrLibrary(qrLibrary));
    }

    /**
     * 修改红外遥控二维码
     */
    @PreAuthorize("@ss.hasPermi('platform:or:edit')")
    @Log(title = "红外遥控二维码", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QrLibrary qrLibrary)
    {
        return toAjax(qrLibraryService.updateQrLibrary(qrLibrary));
    }

    /**
     * 删除红外遥控二维码
     */
    @PreAuthorize("@ss.hasPermi('platform:or:remove')")
    @Log(title = "红外遥控二维码", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(qrLibraryService.deleteQrLibraryByIds(ids));
    }
}
