package com.ruoyi.web.controller.platform;

import java.util.List;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TemplateLibrary;
import com.ruoyi.system.service.TemplateLibraryService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 红外遥控模板库Controller
 * 
 * @author liming
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/platform/v1/template")
public class TemplateLibraryController extends BaseController
{
    @Autowired
    private TemplateLibraryService templateLibraryService;

    /**
     * 查询红外遥控模板库列表
     */
    @PreAuthorize("@ss.hasPermi('platform:template:list')")
    @GetMapping("/list")
    public TableDataInfo list(TemplateLibrary templateLibrary)
    {
        startPage();
        List<TemplateLibrary> list = templateLibraryService.selectTemplateLibraryList(templateLibrary);
        return getDataTable(list);
    }


    /**
     * 获取红外遥控模板库详细信息
     */
    @PreAuthorize("@ss.hasPermi('platform:template:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(templateLibraryService.selectTemplateLibraryById(id));
    }

    /**
     * 新增红外遥控模板库
     */
    @PreAuthorize("@ss.hasPermi('platform:template:add')")
    @Log(title = "红外遥控模板库", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TemplateLibrary templateLibrary)
    {
        return toAjax(templateLibraryService.insertTemplateLibrary(templateLibrary));
    }

    /**
     * 修改红外遥控模板库
     */
    @PreAuthorize("@ss.hasPermi('platform:template:edit')")
    @Log(title = "红外遥控模板库", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TemplateLibrary templateLibrary)
    {
        return toAjax(templateLibraryService.updateTemplateLibrary(templateLibrary));
    }

    /**
     * 删除红外遥控模板库
     */
    @PreAuthorize("@ss.hasPermi('platform:template:remove')")
    @Log(title = "红外遥控模板库", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(templateLibraryService.deleteTemplateLibraryByIds(ids));
    }
}
